==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/es.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'es', {
	acccessKey: 'Tecla de Acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de Contenido',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Referencia',
		menu: 'Propiedades de Referencia',
		title: 'Propiedades de Referencia',
		name: 'Nombre de la Referencia',
		errorName: 'Por favor, complete el nombre de la Referencia',
		remove: 'Quitar Referencia'
	},
	anchorId: 'Por ID de elemento',
	anchorName: 'Por Nombre de Referencia',
	charset: 'Fuente de caracteres vinculado',
	cssClasses: 'Clases de hojas de estilo',
	emailAddress: 'Dirección de E-Mail',
	emailBody: 'Cuerpo del Mensaje',
	emailSubject: 'Título del Mensaje',
	id: 'Id',
	info: 'Información de Vínculo',
	langCode: 'Código idioma',
	langDir: 'Orientación',
	langDirLTR: 'Izquierda a Derecha (LTR)',
	langDirRTL: 'Derecha a Izquierda (RTL)',
	menu: 'Editar Vínculo',
	name: 'Nombre',
	noAnchors: '(No hay referencias disponibles en el documento)',
	noEmail: 'Por favor escriba la dirección de e-mail',
	noUrl: 'Por favor escriba el vínculo URL',
	other: '<otro>',
	popupDependent: 'Dependiente (Netscape)',
	popupFeatures: 'Características de Ventana Emergente',
	popupFullScreen: 'Pantalla Completa (IE)',
	popupLeft: 'Posición Izquierda',
	popupLocationBar: 'Barra de ubicación',
	popupMenuBar: 'Barra de Menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desplazamiento',
	popupStatusBar: 'Barra de Estado',
	popupToolbar: 'Barra de Herramientas',
	popupTop: 'Posición Derecha',
	rel: 'Relación',
	selectAnchor: 'Seleccionar una referencia',
	styles: 'Estilo',
	tabIndex: 'Indice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nombre del Marco Destino',
	targetPopup: '<ventana emergente>',
	targetPopupName: 'Nombre de Ventana Emergente',
	title: 'Vínculo',
	toAnchor: 'Referencia en esta página',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Insertar/Editar Vínculo',
	type: 'Tipo de vínculo',
	unlink: 'Eliminar Vínculo',
	upload: 'Cargar'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/es.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'es', {
	acccessKey: 'Tecla de Acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de Contenido',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Referencia',
		menu: 'Propiedades de Referencia',
		title: 'Propiedades de Referencia',
		name: 'Nombre de la Referencia',
		errorName: 'Por favor, complete el nombre de la Referencia',
		remove: 'Quitar Referencia'
	},
	anchorId: 'Por ID de elemento',
	anchorName: 'Por Nombre de Referencia',
	charset: 'Fuente de caracteres vinculado',
	cssClasses: 'Clases de hojas de estilo',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Dirección de E-Mail',
	emailBody: 'Cuerpo del Mensaje',
	emailSubject: 'Título del Mensaje',
	id: 'Id',
	info: 'Información de Vínculo',
	langCode: 'Código idioma',
	langDir: 'Orientación',
	langDirLTR: 'Izquierda a Derecha (LTR)',
	langDirRTL: 'Derecha a Izquierda (RTL)',
	menu: 'Editar Vínculo',
	name: 'Nombre',
	noAnchors: '(No hay referencias disponibles en el documento)',
	noEmail: 'Por favor escriba la dirección de e-mail',
	noUrl: 'Por favor escriba el vínculo URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<otro>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependiente (Netscape)',
	popupFeatures: 'Características de Ventana Emergente',
	popupFullScreen: 'Pantalla Completa (IE)',
	popupLeft: 'Posición Izquierda',
	popupLocationBar: 'Barra de ubicación',
	popupMenuBar: 'Barra de Menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desplazamiento',
	popupStatusBar: 'Barra de Estado',
	popupToolbar: 'Barra de Herramientas',
	popupTop: 'Posición Derecha',
	rel: 'Relación',
	selectAnchor: 'Seleccionar una referencia',
	styles: 'Estilo',
	tabIndex: 'Indice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nombre del Marco Destino',
	targetPopup: '<ventana emergente>',
	targetPopupName: 'Nombre de Ventana Emergente',
	title: 'Vínculo',
	toAnchor: 'Referencia en esta página',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Insertar/Editar Vínculo',
	type: 'Tipo de vínculo',
	unlink: 'Eliminar Vínculo',
	upload: 'Cargar'
} );
